from distutils.core import setup

setup(
    name = "sussy",
    packages = ["sussy"],
    version = "0.1.3",
    description = "when the python developer is sus",
    long_description="when the impostor is sus\n\nwhen the suspostor is imp\n\n\nwhen the python developer is sus\n\nwhen the susthon developer is py",
    author = "Flamey",
    author_email="morellialex08@gmail.com",
    url = "https://github.com/ActuallyFlamey/sussy/",
    download_url = "https://github.com/ActuallyFlamey/sussy/archive/refs/tags/0.1.0.tar.gz"
)